import { useEffect } from "react";
import { useTagsAndCommitIds, useIocStatus } from "../../../api/SwaggerApi";

function onError(message) {
  console.warn(message);
}

export function IOCDetailFetcher({ ioc, index, setIocs }) {
  const [tagOrCommitId, getTagOrCommitId] = useTagsAndCommitIds(onError);
  const [iocStatus, getIocStatus] = useIocStatus();

  useEffect(() => {
    if (ioc.sourceVersion) {
      getTagOrCommitId(ioc.gitProjectId, ioc.sourceVersion);
    }

    getIocStatus(ioc.id);
  }, [ioc, getTagOrCommitId, getIocStatus]);

  useEffect(() => {
    setIocs((iocs) => {
      iocs[index].sourceVersionShort =
        tagOrCommitId?.length === 1
          ? tagOrCommitId[0].shortReference
          : iocs[index].sourceVersionShort;
      iocs[index].host = iocs[index].activeDeployment?.host;
      iocs[index].alert = iocStatus?.alertSeverity ?? iocs[index].alert;
      iocs[index].active = iocStatus?.active ?? iocs[index].active;
      return [...iocs];
    });
  }, [index, setIocs, tagOrCommitId, iocStatus]);

  return null;
}
