import { Tooltip, useTheme } from "@material-ui/core";
import { PlayArrow, Stop, HelpOutline } from "@material-ui/icons";
import React from "react";

export function IOCStatusIcon({ ioc }) {
  const theme = useTheme();

  const statusBulbColors = {
    true: theme.palette.status.ok,
    false: theme.palette.status.fail,
    null: theme.palette.text.disabled
  };

  const statusBulbIcons = {
    true: (
      <Tooltip title="Active">
        <PlayArrow />
      </Tooltip>
    ),
    false: (
      <Tooltip title="Inactive">
        <Stop />
      </Tooltip>
    ),
    null: (
      <Tooltip title="Unknown">
        <HelpOutline />
      </Tooltip>
    )
  };

  let state = ioc.active ?? null;
  if (!ioc.activeDeployment) state = null;

  const iconStyle = { fill: statusBulbColors[state] };
  const icon = React.cloneElement(statusBulbIcons[state], { style: iconStyle });

  return icon;
}

export function CommandTypeIcon({ type, colorStyle = "colors" }) {
  const theme = useTheme();

  const commandTypeColors = {
    start: theme.palette.status.ok,
    stop: theme.palette.status.fail
  };

  const commandTypeBlack = {
    start: theme.black,
    stop: theme.black
  };

  const colorConfig = {
    black: commandTypeBlack,
    colors: commandTypeColors
  };

  const commandTypeIcons = {
    start: (
      <Tooltip title="Start IOC">
        <PlayArrow />
      </Tooltip>
    ),
    stop: (
      <Tooltip title="Stop IOC">
        <Stop />
      </Tooltip>
    )
  };

  const iconStyle = { fill: colorConfig[colorStyle][type.toLowerCase()] };
  const icon = React.cloneElement(commandTypeIcons[type.toLowerCase()], {
    style: iconStyle
  });

  return icon;
}
