import React, { useCallback, useEffect, useState } from "react";
import {
  TextField,
  Button,
  Dialog,
  DialogContent,
  makeStyles,
  Box,
  LinearProgress
} from "@material-ui/core";
import { Alert } from "@material-ui/lab";

const useStyles = makeStyles((theme) => ({
  textField: {
    marginBottom: theme.spacing(1)
  }
}));

export function LoginForm({ login, error, resetError, onSubmitCallback }) {
  const classes = useStyles();

  const [loading, setLoading] = useState(false);

  const onSubmit = useCallback(
    (event) => {
      event.preventDefault();
      const username = document.getElementById("username").value;
      const password = document.getElementById("password").value;
      login(username, password);
      resetError();
      setLoading(true);
      onSubmitCallback && onSubmitCallback();
    },
    [login, onSubmitCallback, resetError]
  );

  useEffect(() => {
    if (error) {
      setLoading(false);
    }
  }, [error]);

  return (
    <form>
      <TextField
        id="username"
        className={classes.textField}
        label="Username"
        variant="outlined"
        onChange={resetError}
        fullWidth
        autoFocus
        required
      />
      <TextField
        id="password"
        className={classes.textField}
        label="Password"
        variant="outlined"
        type="password"
        onChange={resetError}
        fullWidth
        required
      />
      {error && <Alert severity="error">{error}</Alert>}
      <Button
        fullWidth
        variant="contained"
        color="primary"
        onClick={onSubmit}
        type="submit"
      >
        Login
      </Button>
      {loading && <LinearProgress />}
    </form>
  );
}

export function LoginDialog({
  login,
  open,
  error,
  resetError,
  loading,
  handleClose,
  onSubmitCallback
}) {
  return (
    <Dialog
      fullWidth
      open={open}
      onClose={handleClose}
    >
      <DialogContent>
        <Box marginY={1}>
          <LoginForm
            login={login}
            error={error}
            resetError={resetError}
            onSubmitCallback={onSubmitCallback}
            loading={loading}
          />
        </Box>
      </DialogContent>
    </Dialog>
  );
}
