import React from "react";
import { CustomTable } from "../table/CustomTable";
import { Skeleton } from "primereact/skeleton";

export function PrimeKeyValueTable(
  { obj, labels = ["Key", "Value"] },
  valueWidth = "15ch"
) {
  const bodyTemplate = (rowData) => {
    return rowData.value ?? <Skeleton />;
  };

  const defaultColumns = [
    { id: "key", label: labels[0] },
    {
      id: "value",
      label: labels[1],
      width: valueWidth,
      body: bodyTemplate,
      textAlign: "right"
    }
  ];

  // even though they are unused, we have to give the
  // CustomTable some pagination args or it just won't work
  return (
    <CustomTable
      columns={defaultColumns}
      rows={Object.entries(obj).map(([key, value]) => ({ key, value }))}
      paginator={false}
      totalCount={Object.entries(obj).length}
      rowsPerPage={[5, 10, 20, 50, 100]}
      lazyParams={{ rows: 10, page: 0 }}
      columnSort={{ sortField: null, sortOrder: null }}
      setLazyParams={() => {}}
      setColumnSort={() => {}}
    />
  );
}
